@@ -28,6 +28,7 @@ import (
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/env"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/incidents"
 	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/metrics"
 	"github.com/superfly/flyctl/internal/state"
@@ -64,11 +65,13 @@ var commonPreparers = []preparers.Preparer{
 	startQueryingForNewRelease,
 	promptAndAutoUpdate,
 	startMetrics,
+	notifyStatuspageIncidents,
 }
 
 var authPreparers = []preparers.Preparer{
 	preparers.InitClient,
 	killOldAgent,
+	notifyHostIssues,
 }
 
 func sendOsMetric(ctx context.Context, state string) {
@@ -502,6 +505,41 @@ func startMetrics(ctx context.Context) (context.Context, error) {
 	return ctx, nil
 }
 
+func notifyStatuspageIncidents(ctx context.Context) (context.Context, error) {
+	if shouldIgnore(ctx, [][]string{
+		{"incidents", "list"},
+	}) {
+		return ctx, nil
+	}
+
+	if !incidents.Check() {
+		return ctx, nil
+	}
+
+	incidents.QueryStatuspageIncidents(ctx)
+
+	return ctx, nil
+}
+
+func notifyHostIssues(ctx context.Context) (context.Context, error) {
+	if shouldIgnore(ctx, [][]string{
+		{"incidents", "hosts", "list"},
+	}) {
+		return ctx, nil
+	}
+
+	if !incidents.Check() {
+		return ctx, nil
+	}
+
+	appCtx, err := LoadAppNameIfPresent(ctx)
+	if err == nil {
+		incidents.QueryHostIssues(appCtx)
+	}
+
+	return ctx, nil
+}
+
 func ExcludeFromMetrics(ctx context.Context) (context.Context, error) {
 	metrics.Enabled = false
 	return ctx, nil
