@@ -203,6 +203,7 @@ func buildManifest(ctx context.Context, recoverableErrors *recoverableErrorBuild
 		computeSource:  computeExplanation,
 		postgresSource: "not requested",
 		redisSource:    "not requested",
+		tigrisSource:   "not requested",
 		sentrySource:   "not requested",
 	}
 
@@ -232,6 +233,10 @@ func buildManifest(ctx context.Context, recoverableErrors *recoverableErrorBuild
 			lp.Redis = plan.DefaultRedis(lp)
 			planSource.redisSource = scannerSource
 		}
+		if srcInfo.ObjectStorageDesired {
+			lp.ObjectStorage = plan.DefaultObjectStorage(lp)
+			planSource.tigrisSource = scannerSource
+		}
 		if srcInfo.Port != 0 {
 			lp.HttpServicePort = srcInfo.Port
 			lp.HttpServicePortSetByScanner = true
@@ -521,7 +526,12 @@ func determineOrg(ctx context.Context) (*fly.Organization, string, error) {
 	orgSlug := flag.GetOrg(ctx)
 	if orgSlug == "" {
 		if !foundPersonal {
-			return nil, "", errors.New("no personal organization found")
+			if len(orgs) == 0 {
+				return nil, "", errors.New("no organizations found. Please create one from your fly dashboard first.")
+			} else {
+				o := orgs[0]
+				return &o, fmt.Sprintf("defaulting to '%s'", o.Slug), nil
+			}
 		}
 
 		return &personal, "fly launch defaults to the personal org", nil
