@@ -49,6 +49,7 @@ type Client struct {
 	GetAppCertificatesFunc             func(ctx context.Context, appName string) ([]fly.AppCertificateCompact, error)
 	GetAppCompactFunc                  func(ctx context.Context, appName string) (*fly.AppCompact, error)
 	GetAppCurrentReleaseMachinesFunc   func(ctx context.Context, appName string) (*fly.Release, error)
+	GetAppHostIssuesFunc               func(ctx context.Context, appName string) ([]fly.HostIssue, error)
 	GetAppLimitedAccessTokensFunc      func(ctx context.Context, appName string) ([]fly.LimitedAccessToken, error)
 	GetAppLogsFunc                     func(ctx context.Context, appName, token, region, instanceID string) (entries []fly.LogEntry, nextToken string, err error)
 	GetAppNameFromVolumeFunc           func(ctx context.Context, volID string) (*string, error)
@@ -237,6 +238,10 @@ func (m *Client) GetAppCurrentReleaseMachines(ctx context.Context, appName strin
 	return m.GetAppCurrentReleaseMachinesFunc(ctx, appName)
 }
 
+func (m *Client) GetAppHostIssues(ctx context.Context, appName string) ([]fly.HostIssue, error) {
+	return m.GetAppHostIssuesFunc(ctx, appName)
+}
+
 func (m *Client) GetAppLimitedAccessTokens(ctx context.Context, appName string) ([]fly.LimitedAccessToken, error) {
 	return m.GetAppLimitedAccessTokensFunc(ctx, appName)
 }
